@@ -43,7 +43,7 @@ public:
      */
     void setCurrentFunction(int functionID);
 
-public slots:
+public Q_SLOTS:
     /**
      * Deletes the current selected function.
      */
@@ -73,7 +73,7 @@ public slots:
      */
     void functionsChanged();
 
-protected slots:
+protected Q_SLOTS:
     /**
      * Called when a function in the list is selected.
      */
@@ -194,11 +194,7 @@ public:
 protected:
     void dragEnterEvent(QDragEnterEvent *event) override;
     void dropEvent(QDropEvent *event) override;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
-#else
     QMimeData *mimeData(const QList<QListWidgetItem *> &items) const override;
-#endif
     QStringList mimeTypes() const override;
 };
 
